# selenium_firefox
![python_version](https://img.shields.io/static/v1?label=Python&message=3.5%20|%203.6%20|%203.7&color=blue) [![PyPI download month](https://img.shields.io/pypi/dm/selenium-firefox?logo=pypi&logoColor=white)](https://pypi.python.org/pypi/selenium-firefox/) [![PyPI version](https://img.shields.io/pypi/v/selenium-firefox?logo=pypi&logoColor=white)](https://pypi.python.org/pypi/selenium-firefox/)

## Features
- Easily create a firefox selenium webdriver with proxy(host/port), extensions and other settings, such as, full-screen-window,
private session.
- Override user-agent
- Easily save and load cookies for websites

## Install
~~~~
pip3 install selenium-firefox
~~~~

## Dependencies

[geckodriver-autoinstaller](https://pypi.org/project/geckodriver-autoinstaller), [noraise](https://pypi.org/project/noraise), [selenium](https://pypi.org/project/selenium), [tldextract](https://pypi.org/project/tldextract)